# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fqwak/automation/v1/common.proto\x12\x12qwak.automation.v1\"G\n\x06Metric\x12\x33\n\nsql_metric\x18\x01 \x01(\x0b\x32\x1d.qwak.automation.v1.SqlMetricH\x00\x42\x08\n\x06metric\"\x1e\n\tSqlMetric\x12\x11\n\tsql_query\x18\x01 \x01(\t*\x84\x01\n\x18MetricThresholdDirection\x12\x1c\n\x18INVALID_METRIC_DIRECTION\x10\x00\x12\t\n\x05\x42\x45LOW\x10\x01\x12\t\n\x05\x41\x42OVE\x10\x02\x12\n\n\x06\x45QUALS\x10\x03\x12\x13\n\x0f\x42\x45LOW_OR_EQUALS\x10\x04\x12\x13\n\x0f\x41\x42OVE_OR_EQUALS\x10\x05\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _globals['_METRICTHRESHOLDDIRECTION']._serialized_start=161
  _globals['_METRICTHRESHOLDDIRECTION']._serialized_end=293
  _globals['_METRIC']._serialized_start=55
  _globals['_METRIC']._serialized_end=126
  _globals['_SQLMETRIC']._serialized_start=128
  _globals['_SQLMETRIC']._serialized_end=158
# @@protoc_insertion_point(module_scope)
