# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/build_settings/build_settings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/build_settings/build_settings.proto\x12\x17\x63om.qwak.build_settings\"c\n\rBuildSettings\x12R\n\x18model_repository_setting\x18\x01 \x01(\x0b\x32\x30.com.qwak.build_settings.ModelRepositorySettings\"\xcc\x02\n\x17ModelRepositorySettings\x12!\n\x19\x63ontainer_registry_prefix\x18\x01 \x01(\t\x12Q\n\x17repository_settings_ecr\x18\x02 \x01(\x0b\x32..com.qwak.build_settings.RepositorySettingsECRH\x00\x12U\n\x19repository_settings_jfrog\x18\x03 \x01(\x0b\x32\x30.com.qwak.build_settings.RepositorySettingsJFrogH\x00\x12Q\n\x17repository_settings_gcr\x18\x04 \x01(\x0b\x32..com.qwak.build_settings.RepositorySettingsGCRH\x00\x42\x11\n\x0frepository_type\"\xe2\x01\n\x17RepositorySettingsJFrog\x12P\n\x17\x61uthentication_settings\x18\x01 \x01(\x0b\x32/.com.qwak.build_settings.AuthenticationSettings\x12\x1a\n\x12jfrog_project_name\x18\x02 \x01(\t\x12Y\n\x1c\x65xternal_repository_settings\x18\x03 \x01(\x0b\x32\x33.com.qwak.build_settings.ExternalRepositorySettings\"\xb3\x01\n\x1a\x45xternalRepositorySettings\x12\x19\n\x11python_repository\x18\x01 \x03(\t\x12\x1e\n\x16huggingface_repository\x18\x02 \x01(\t\x12*\n\"allow_external_python_repositories\x18\x03 \x01(\x08\x12.\n&virtual_python_dependencies_repository\x18\x04 \x01(\t\"9\n\x16\x41uthenticationSettings\x12\r\n\x05token\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\"\x17\n\x15RepositorySettingsECR\"\x17\n\x15RepositorySettingsGCRB/\n\x17\x63om.qwak.build_settingsB\x12\x42uildSettingsProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.build_settings.build_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.qwak.build_settingsB\022BuildSettingsProtoP\001'
  _globals['_BUILDSETTINGS']._serialized_start=69
  _globals['_BUILDSETTINGS']._serialized_end=168
  _globals['_MODELREPOSITORYSETTINGS']._serialized_start=171
  _globals['_MODELREPOSITORYSETTINGS']._serialized_end=503
  _globals['_REPOSITORYSETTINGSJFROG']._serialized_start=506
  _globals['_REPOSITORYSETTINGSJFROG']._serialized_end=732
  _globals['_EXTERNALREPOSITORYSETTINGS']._serialized_start=735
  _globals['_EXTERNALREPOSITORYSETTINGS']._serialized_end=914
  _globals['_AUTHENTICATIONSETTINGS']._serialized_start=916
  _globals['_AUTHENTICATIONSETTINGS']._serialized_end=973
  _globals['_REPOSITORYSETTINGSECR']._serialized_start=975
  _globals['_REPOSITORYSETTINGSECR']._serialized_end=998
  _globals['_REPOSITORYSETTINGSGCR']._serialized_start=1000
  _globals['_REPOSITORYSETTINGSGCR']._serialized_end=1023
# @@protoc_insertion_point(module_scope)
