# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/batch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/feature_store/sources/batch.proto\x12\x1aqwak.feature.store.sources\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x07\n\x0b\x42\x61tchSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x61te_created_column\x18\x03 \x01(\t\x12@\n\x0c\x61thenaSource\x18\x04 \x01(\x0b\x32(.qwak.feature.store.sources.AthenaSourceH\x00\x12>\n\x0bmongoSource\x18\x05 \x01(\x0b\x32\'.qwak.feature.store.sources.MongoSourceH\x00\x12:\n\tcsvSource\x18\x06 \x01(\x0b\x32%.qwak.feature.store.sources.CsvSourceH\x00\x12\x46\n\x0fsnowflakeSource\x18\x07 \x01(\x0b\x32+.qwak.feature.store.sources.SnowflakeSourceH\x00\x12\x42\n\rparquetSource\x18\x08 \x01(\x0b\x32).qwak.feature.store.sources.ParquetSourceH\x00\x12<\n\njdbcSource\x18\t \x01(\x0b\x32&.qwak.feature.store.sources.JdbcSourceH\x00\x12\x42\n\rverticaSource\x18\n \x01(\x0b\x32).qwak.feature.store.sources.VerticaSourceH\x00\x12\x44\n\x0e\x62igquerySource\x18\x0b \x01(\x0b\x32*.qwak.feature.store.sources.BigquerySourceH\x00\x12N\n\x13\x65lasticsearchSource\x18\x0c \x01(\x0b\x32/.qwak.feature.store.sources.ElasticsearchSourceH\x00\x12H\n\x10\x63lickhouseSource\x18\r \x01(\x0b\x32,.qwak.feature.store.sources.ClickhouseSourceH\x00\x12V\n\x17\x66\x65\x61turesetOfflineSource\x18\x0e \x01(\x0b\x32\x33.qwak.feature.store.sources.FeaturesetOfflineSourceH\x00\x12J\n\x11tableFormatSource\x18\x0f \x01(\x0b\x32-.qwak.feature.store.sources.TableFormatSourceH\x00\x42\x06\n\x04type\"\xae\x04\n\x17\x46ileSystemConfiguration\x12X\n\x14\x61ws_s3_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.sources.AwsS3FileSystemConfigurationH\x00\x12P\n\x10\x61ws_s3_anonymous\x18\x02 \x01(\x0b\x32\x34.qwak.feature.store.sources.AnonymousS3ConfigurationH\x00\x12W\n aws_s3_assume_role_configuration\x18\x03 \x01(\x0b\x32+.qwak.feature.store.sources.AwsS3AssumeRoleH\x00\x12M\n\x13gcs_unauthenticated\x18\x04 \x01(\x0b\x32..qwak.feature.store.sources.GcsUnauthenticatedH\x00\x12N\n\x14gcs_user_credentials\x18\x05 \x01(\x0b\x32..qwak.feature.store.sources.GcsUserCredentialsH\x00\x12g\n!gcs_service_account_impersonation\x18\x06 \x01(\x0b\x32:.qwak.feature.store.sources.GcsServiceAccountImpersonationH\x00\x42\x06\n\x04type\"#\n\x0f\x41wsS3AssumeRole\x12\x10\n\x08role_arn\x18\x01 \x01(\t\"\x91\x01\n\x1c\x41wsS3FileSystemConfiguration\x12\x1e\n\x16\x61\x63\x63\x65ss_key_secret_name\x18\x01 \x01(\t\x12\x1e\n\x16secret_key_secret_name\x18\x02 \x01(\t\x12!\n\x19session_token_secret_name\x18\x03 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x04 \x01(\t\"\x1a\n\x18\x41nonymousS3Configuration\"\x92\x03\n\nJdbcSource\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x01 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x02 \x01(\t\x12\x10\n\x08\x64\x62_table\x18\x04 \x01(\t\x12\r\n\x05query\x18\x05 \x01(\t\x12>\n\x0bmysqlSource\x18\x06 \x01(\x0b\x32\'.qwak.feature.store.sources.MysqlSourceH\x00\x12H\n\x10postgresqlSource\x18\x07 \x01(\x0b\x32,.qwak.feature.store.sources.PostgresqlSourceH\x00\x12\x44\n\x0eredshiftSource\x18\x08 \x01(\x0b\x32*.qwak.feature.store.sources.RedshiftSourceH\x00\x12\x42\n\x0c\x61thenaSource\x18\t \x01(\x0b\x32*.qwak.feature.store.sources.AthenaSourceV1H\x00\x42\x06\n\x04type\"\r\n\x0bMysqlSource\"\x12\n\x10PostgresqlSource\"\x89\x01\n\x10\x43lickhouseSource\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x02 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x03 \x01(\t\x12\x0f\n\x05table\x18\x04 \x01(\tH\x00\x12\r\n\x03sql\x18\x05 \x01(\tH\x00\x42\x0c\n\nquery_type\"i\n\x0eRedshiftSource\x12\x0f\n\x07\x64\x62_user\x18\x01 \x01(\t\x12\x14\n\x0ciam_role_arn\x18\x02 \x01(\t\x12\x15\n\raccess_key_id\x18\x03 \x01(\t\x12\x19\n\x11secret_access_key\x18\x04 \x01(\t\"\x8d\x03\n\x0e\x41thenaSourceV1\x12\x12\n\naws_region\x18\x01 \x01(\t\x12I\n\x12\x61ws_authentication\x18\x02 \x01(\x0b\x32-.qwak.feature.store.sources.AwsAuthentication\x12\x1a\n\x12s3_output_location\x18\x03 \x01(\t\x12R\n\x16\x64\x61te_partition_columns\x18\x04 \x01(\x0b\x32\x30.qwak.feature.store.sources.DatePartitionColumnsH\x00\x12g\n!time_fragmented_partition_columns\x18\x05 \x01(\x0b\x32:.qwak.feature.store.sources.TimeFragmentedPartitionColumnsH\x00\x12\x13\n\tworkgroup\x18\x06 \x01(\tH\x01\x42\x18\n\x16time_partition_columnsB\x14\n\x12optional_workgroup\"E\n\x14\x44\x61tePartitionColumns\x12\x18\n\x10\x64\x61te_column_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61te_format\x18\x02 \x01(\t\"\xb5\x02\n\x1eTimeFragmentedPartitionColumns\x12M\n\x15year_partition_column\x18\x01 \x01(\x0b\x32..qwak.feature.store.sources.YearFragmentColumn\x12Q\n\x16month_partition_column\x18\x02 \x01(\x0b\x32/.qwak.feature.store.sources.MonthFragmentColumnH\x00\x12M\n\x14\x64\x61y_partition_column\x18\x03 \x01(\x0b\x32-.qwak.feature.store.sources.DayFragmentColumnH\x01\x42\x11\n\x0fmonth_partitionB\x0f\n\rday_partition\"\xa4\x01\n\x12YearFragmentColumn\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12`\n\x1dnumeric_column_representation\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.sources.NumericColumnRepresentationH\x00\x42\x17\n\x15\x63olumn_representation\"\x87\x02\n\x13MonthFragmentColumn\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12`\n\x1dnumeric_column_representation\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.sources.NumericColumnRepresentationH\x00\x12`\n\x1dtextual_column_representation\x18\x03 \x01(\x0b\x32\x37.qwak.feature.store.sources.TextualColumnRepresentationH\x00\x42\x17\n\x15\x63olumn_representation\"\xa3\x01\n\x11\x44\x61yFragmentColumn\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12`\n\x1dnumeric_column_representation\x18\x02 \x01(\x0b\x32\x37.qwak.feature.store.sources.NumericColumnRepresentationH\x00\x42\x17\n\x15\x63olumn_representation\"\x1d\n\x1bNumericColumnRepresentation\"\x1d\n\x1bTextualColumnRepresentation\"/\n\x0c\x41thenaSource\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\"\xa0\x02\n\x0e\x42igquerySource\x12\x1f\n\x17\x63redentials_secret_name\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\x02 \x01(\t\x12\r\n\x05table\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x16\n\x0eparent_project\x18\x05 \x01(\t\x12\x0b\n\x03sql\x18\x06 \x01(\t\x12\x15\n\rviews_enabled\x18\x07 \x01(\x08\x12#\n\x17materialization_dataset\x18\x08 \x01(\tB\x02\x18\x01\x12#\n\x17materialization_project\x18\t \x01(\tB\x02\x18\x01\x12\x36\n*materialization_expiration_time_in_minutes\x18\n \x01(\tB\x02\x18\x01\"\xa3\x01\n\tCsvSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x17\n\x0fquote_character\x18\x02 \x01(\t\x12\x18\n\x10\x65scape_character\x18\x03 \x01(\t\x12U\n\x18\x66ilesystem_configuration\x18\x04 \x01(\x0b\x32\x33.qwak.feature.store.sources.FileSystemConfiguration\"\xab\x01\n\x0bMongoSource\x12\r\n\x05hosts\x18\x01 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x02 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x03 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x12\n\ncollection\x18\x05 \x01(\t\x12\x19\n\x11\x63onnection_params\x18\x06 \x01(\t\x12\x10\n\x08protocol\x18\x07 \x01(\t\"\xea\x01\n\x0fSnowflakeSource\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x02 \x01(\t\x12\"\n\x14password_secret_name\x18\x03 \x01(\tB\x02\x18\x01H\x00\x12%\n\x1bpem_private_key_secret_name\x18\t \x01(\tH\x00\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12\x11\n\twarehouse\x18\x06 \x01(\t\x12\r\n\x05table\x18\x07 \x01(\t\x12\r\n\x05query\x18\x08 \x01(\tB\r\n\x0b\x61uth_secret\"t\n\rParquetSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12U\n\x18\x66ilesystem_configuration\x18\x02 \x01(\x0b\x32\x33.qwak.feature.store.sources.FileSystemConfiguration\"\x98\x01\n\rVerticaSource\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08\x64\x61tabase\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12\r\n\x05table\x18\x05 \x01(\t\x12\x1c\n\x14username_secret_name\x18\x06 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x07 \x01(\t\"\xbc\x01\n\x13\x45lasticsearchSource\x12\r\n\x05nodes\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08resource\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x16\n\x0e\x65xclude_fields\x18\x05 \x01(\t\x12\x13\n\x0bparse_dates\x18\x06 \x01(\x08\x12\x1c\n\x14username_secret_name\x18\x07 \x01(\t\x12\x1c\n\x14password_secret_name\x18\x08 \x01(\t\"X\n\x11TableFormatSource\x12\x34\n\x07\x63\x61talog\x18\x01 \x01(\x0b\x32#.qwak.feature.store.sources.Catalog\x12\r\n\x05query\x18\x02 \x01(\t\"S\n\x07\x43\x61talog\x12@\n\x0cunityCatalog\x18\x01 \x01(\x0b\x32(.qwak.feature.store.sources.UnityCatalogH\x00\x42\x06\n\x04type\"g\n\x0cUnityCatalog\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61talog\x18\x02 \x01(\t\x12+\n!personal_access_token_secret_name\x18\x03 \x01(\tH\x00\x42\x0b\n\tauth_type\"(\n\x17\x46\x65\x61turesetOfflineSource\x12\r\n\x05\x61lias\x18\x01 \x01(\t\"\xe9\x01\n\x11\x41wsAuthentication\x12\x61\n\x1e\x61ws_assume_role_authentication\x18\x01 \x01(\x0b\x32\x37.qwak.feature.store.sources.AwsAssumeRoleAuthenticationH\x00\x12i\n%aws_static_credentials_authentication\x18\x02 \x01(\x0b\x32\x38.qwak.feature.store.sources.AwsCredentialsAuthenticationH\x00\x42\x06\n\x04type\"/\n\x1b\x41wsAssumeRoleAuthentication\x12\x10\n\x08role_arn\x18\x01 \x01(\t\"^\n\x1c\x41wsCredentialsAuthentication\x12\x1e\n\x16\x61\x63\x63\x65ss_key_secret_name\x18\x01 \x01(\t\x12\x1e\n\x16secret_key_secret_name\x18\x02 \x01(\t\"\x14\n\x12GcsUnauthenticated\"y\n\x12GcsUserCredentials\x12\x1d\n\x15\x63lient_id_secret_name\x18\x01 \x01(\t\x12!\n\x19\x63lient_secret_secret_name\x18\x02 \x01(\t\x12!\n\x19refresh_token_secret_name\x18\x03 \x01(\t\">\n\x1eGcsServiceAccountImpersonation\x12\x1c\n\x14service_account_user\x18\x01 \x01(\tBX\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sources.batch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _BIGQUERYSOURCE.fields_by_name['materialization_dataset']._options = None
  _BIGQUERYSOURCE.fields_by_name['materialization_dataset']._serialized_options = b'\030\001'
  _BIGQUERYSOURCE.fields_by_name['materialization_project']._options = None
  _BIGQUERYSOURCE.fields_by_name['materialization_project']._serialized_options = b'\030\001'
  _BIGQUERYSOURCE.fields_by_name['materialization_expiration_time_in_minutes']._options = None
  _BIGQUERYSOURCE.fields_by_name['materialization_expiration_time_in_minutes']._serialized_options = b'\030\001'
  _SNOWFLAKESOURCE.fields_by_name['password_secret_name']._options = None
  _SNOWFLAKESOURCE.fields_by_name['password_secret_name']._serialized_options = b'\030\001'
  _globals['_BATCHSOURCE']._serialized_start=104
  _globals['_BATCHSOURCE']._serialized_end=1037
  _globals['_FILESYSTEMCONFIGURATION']._serialized_start=1040
  _globals['_FILESYSTEMCONFIGURATION']._serialized_end=1598
  _globals['_AWSS3ASSUMEROLE']._serialized_start=1600
  _globals['_AWSS3ASSUMEROLE']._serialized_end=1635
  _globals['_AWSS3FILESYSTEMCONFIGURATION']._serialized_start=1638
  _globals['_AWSS3FILESYSTEMCONFIGURATION']._serialized_end=1783
  _globals['_ANONYMOUSS3CONFIGURATION']._serialized_start=1785
  _globals['_ANONYMOUSS3CONFIGURATION']._serialized_end=1811
  _globals['_JDBCSOURCE']._serialized_start=1814
  _globals['_JDBCSOURCE']._serialized_end=2216
  _globals['_MYSQLSOURCE']._serialized_start=2218
  _globals['_MYSQLSOURCE']._serialized_end=2231
  _globals['_POSTGRESQLSOURCE']._serialized_start=2233
  _globals['_POSTGRESQLSOURCE']._serialized_end=2251
  _globals['_CLICKHOUSESOURCE']._serialized_start=2254
  _globals['_CLICKHOUSESOURCE']._serialized_end=2391
  _globals['_REDSHIFTSOURCE']._serialized_start=2393
  _globals['_REDSHIFTSOURCE']._serialized_end=2498
  _globals['_ATHENASOURCEV1']._serialized_start=2501
  _globals['_ATHENASOURCEV1']._serialized_end=2898
  _globals['_DATEPARTITIONCOLUMNS']._serialized_start=2900
  _globals['_DATEPARTITIONCOLUMNS']._serialized_end=2969
  _globals['_TIMEFRAGMENTEDPARTITIONCOLUMNS']._serialized_start=2972
  _globals['_TIMEFRAGMENTEDPARTITIONCOLUMNS']._serialized_end=3281
  _globals['_YEARFRAGMENTCOLUMN']._serialized_start=3284
  _globals['_YEARFRAGMENTCOLUMN']._serialized_end=3448
  _globals['_MONTHFRAGMENTCOLUMN']._serialized_start=3451
  _globals['_MONTHFRAGMENTCOLUMN']._serialized_end=3714
  _globals['_DAYFRAGMENTCOLUMN']._serialized_start=3717
  _globals['_DAYFRAGMENTCOLUMN']._serialized_end=3880
  _globals['_NUMERICCOLUMNREPRESENTATION']._serialized_start=3882
  _globals['_NUMERICCOLUMNREPRESENTATION']._serialized_end=3911
  _globals['_TEXTUALCOLUMNREPRESENTATION']._serialized_start=3913
  _globals['_TEXTUALCOLUMNREPRESENTATION']._serialized_end=3942
  _globals['_ATHENASOURCE']._serialized_start=3944
  _globals['_ATHENASOURCE']._serialized_end=3991
  _globals['_BIGQUERYSOURCE']._serialized_start=3994
  _globals['_BIGQUERYSOURCE']._serialized_end=4282
  _globals['_CSVSOURCE']._serialized_start=4285
  _globals['_CSVSOURCE']._serialized_end=4448
  _globals['_MONGOSOURCE']._serialized_start=4451
  _globals['_MONGOSOURCE']._serialized_end=4622
  _globals['_SNOWFLAKESOURCE']._serialized_start=4625
  _globals['_SNOWFLAKESOURCE']._serialized_end=4859
  _globals['_PARQUETSOURCE']._serialized_start=4861
  _globals['_PARQUETSOURCE']._serialized_end=4977
  _globals['_VERTICASOURCE']._serialized_start=4980
  _globals['_VERTICASOURCE']._serialized_end=5132
  _globals['_ELASTICSEARCHSOURCE']._serialized_start=5135
  _globals['_ELASTICSEARCHSOURCE']._serialized_end=5323
  _globals['_TABLEFORMATSOURCE']._serialized_start=5325
  _globals['_TABLEFORMATSOURCE']._serialized_end=5413
  _globals['_CATALOG']._serialized_start=5415
  _globals['_CATALOG']._serialized_end=5498
  _globals['_UNITYCATALOG']._serialized_start=5500
  _globals['_UNITYCATALOG']._serialized_end=5603
  _globals['_FEATURESETOFFLINESOURCE']._serialized_start=5605
  _globals['_FEATURESETOFFLINESOURCE']._serialized_end=5645
  _globals['_AWSAUTHENTICATION']._serialized_start=5648
  _globals['_AWSAUTHENTICATION']._serialized_end=5881
  _globals['_AWSASSUMEROLEAUTHENTICATION']._serialized_start=5883
  _globals['_AWSASSUMEROLEAUTHENTICATION']._serialized_end=5930
  _globals['_AWSCREDENTIALSAUTHENTICATION']._serialized_start=5932
  _globals['_AWSCREDENTIALSAUTHENTICATION']._serialized_end=6026
  _globals['_GCSUNAUTHENTICATED']._serialized_start=6028
  _globals['_GCSUNAUTHENTICATED']._serialized_end=6048
  _globals['_GCSUSERCREDENTIALS']._serialized_start=6050
  _globals['_GCSUSERCREDENTIALS']._serialized_end=6171
  _globals['_GCSSERVICEACCOUNTIMPERSONATION']._serialized_start=6173
  _globals['_GCSSERVICEACCOUNTIMPERSONATION']._serialized_end=6235
# @@protoc_insertion_point(module_scope)
