"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.features.feature_set_pb2
import qwak.feature_store.sources.data_source_pb2
import qwak.features_operator.v2.features_operator_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ValidateDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_SPEC_FIELD_NUMBER: builtins.int
    NUM_SAMPLES_FIELD_NUMBER: builtins.int
    ZIP_PATH_FIELD_NUMBER: builtins.int
    @property
    def data_source_spec(self) -> qwak.feature_store.sources.data_source_pb2.DataSourceSpec:
        """Data source spec to validate"""
    num_samples: builtins.int
    """Number of samples to return from the validation"""
    zip_path: builtins.str
    """Dependencies zip file path"""
    def __init__(
        self,
        *,
        data_source_spec: qwak.feature_store.sources.data_source_pb2.DataSourceSpec | None = ...,
        num_samples: builtins.int = ...,
        zip_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec", "num_samples", b"num_samples", "zip_path", b"zip_path"]) -> None: ...

global___ValidateDataSourceRequest = ValidateDataSourceRequest

class ValidateFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    ZIP_PATH_FIELD_NUMBER: builtins.int
    NUM_SAMPLES_FIELD_NUMBER: builtins.int
    @property
    def feature_set_spec(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetSpec:
        """Featureset spec to validate"""
    zip_path: builtins.str
    """Dependencies zip file path"""
    num_samples: builtins.int
    """Number of samples to return from the validation"""
    def __init__(
        self,
        *,
        feature_set_spec: qwak.feature_store.features.feature_set_pb2.FeatureSetSpec | None = ...,
        zip_path: builtins.str = ...,
        num_samples: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec", "num_samples", b"num_samples", "zip_path", b"zip_path"]) -> None: ...

global___ValidateFeatureSetRequest = ValidateFeatureSetRequest

class ValidationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_RESPONSE_FIELD_NUMBER: builtins.int
    FAILURE_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def success_response(self) -> qwak.features_operator.v2.features_operator_pb2.ValidationSuccessResponse: ...
    @property
    def failure_response(self) -> qwak.features_operator.v2.features_operator_pb2.ValidationFailureResponse: ...
    def __init__(
        self,
        *,
        success_response: qwak.features_operator.v2.features_operator_pb2.ValidationSuccessResponse | None = ...,
        failure_response: qwak.features_operator.v2.features_operator_pb2.ValidationFailureResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure_response", b"failure_response", "success_response", b"success_response", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_response", b"failure_response", "success_response", b"success_response", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["success_response", "failure_response"] | None: ...

global___ValidationResponse = ValidationResponse
