"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.external.redis_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeatureStoreConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def enabled(self) -> global___EnabledFeatureStoreConfiguration: ...
    def __init__(
        self,
        *,
        enabled: global___EnabledFeatureStoreConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "toggle", b"toggle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "toggle", b"toggle"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["toggle", b"toggle"]) -> typing_extensions.Literal["enabled"] | None: ...

global___FeatureStoreConfiguration = FeatureStoreConfiguration

class EnabledFeatureStoreConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_FEATURE_STORE_FIELD_NUMBER: builtins.int
    @property
    def online_feature_store(self) -> global___OnlineFeatureStore: ...
    def __init__(
        self,
        *,
        online_feature_store: global___OnlineFeatureStore | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["online_feature_store", b"online_feature_store"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_feature_store", b"online_feature_store"]) -> None: ...

global___EnabledFeatureStoreConfiguration = EnabledFeatureStoreConfiguration

class OnlineFeatureStore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDIS_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def redis_configuration(self) -> qwak.administration.runtime_configuration.v0.external.redis_config_pb2.RedisConfiguration: ...
    def __init__(
        self,
        *,
        redis_configuration: qwak.administration.runtime_configuration.v0.external.redis_config_pb2.RedisConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["redis_configuration", b"redis_configuration", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["redis_configuration", b"redis_configuration", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["redis_configuration"] | None: ...

global___OnlineFeatureStore = OnlineFeatureStore
