# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/hosting_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0.hosting.aws import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_hosting_dot_aws_dot_auth__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0.hosting.azure import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_hosting_dot_azure_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAqwak/administration/runtime_configuration/v0/hosting_config.proto\x12;qwak.administration.runtime_configuration.v0.hosting_config\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\x1a\x43qwak/administration/runtime_configuration/v0/hosting/aws/auth.proto\x1a\x45qwak/administration/runtime_configuration/v0/hosting/azure/auth.proto\"\x8a\x03\n\x14HostingConfiguration\x12v\n\x16\x61ws_host_configuration\x18\x01 \x01(\x0b\x32T.qwak.administration.runtime_configuration.v0.hosting_config.AWSHostingConfigurationH\x00\x12v\n\x16gcp_host_configuration\x18\x02 \x01(\x0b\x32T.qwak.administration.runtime_configuration.v0.hosting_config.GCPHostingConfigurationH\x00\x12z\n\x18\x61zure_host_configuration\x18\x03 \x01(\x0b\x32V.qwak.administration.runtime_configuration.v0.hosting_config.AzureHostingConfigurationH\x00\x42\x06\n\x04type\"\x8e\x02\n\x17\x41WSHostingConfiguration\x12m\n\x13iam_service_account\x18\x01 \x01(\x0b\x32N.qwak.administration.runtime_configuration.v0.hosting_config.IAMServiceAccountH\x00\x12l\n\x12scoped_permissions\x18\x03 \x01(\x0b\x32N.qwak.administration.runtime_configuration.v0.hosting.aws.AWSScopedPermissionsH\x00\x12\x0e\n\x06region\x18\x02 \x01(\tB\x06\n\x04\x61uth\"\xb8\x01\n\x17GCPHostingConfiguration\x12q\n\x13gcp_service_account\x18\x01 \x01(\x0b\x32R.qwak.administration.runtime_configuration.v0.hosting_config.GCPServiceAccountAuthH\x00\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\tB\x06\n\x04\x61uth\"\xe7\x01\n\x15GCPServiceAccountAuth\x12g\n\x0fservice_account\x18\x01 \x01(\x0b\x32N.qwak.administration.runtime_configuration.v0.hosting_config.IAMServiceAccount\x12\x65\n\x14service_account_json\x18\x02 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRef\"&\n\x11IAMServiceAccount\x12\x11\n\trole_name\x18\x01 \x01(\t\"\xa9\x01\n\x19\x41zureHostingConfiguration\x12\x63\n\nazure_auth\x18\x01 \x01(\x0b\x32O.qwak.administration.runtime_configuration.v0.hosting.azure.AzureAuthentication\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x17\n\x0f\x61zure_tenant_id\x18\x03 \x01(\tB\xdb\x01\n4com.jfrog.ml.runtime_configuration.v0.hosting_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.hosting_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.jfrog.ml.runtime_configuration.v0.hosting_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _globals['_HOSTINGCONFIGURATION']._serialized_start=336
  _globals['_HOSTINGCONFIGURATION']._serialized_end=730
  _globals['_AWSHOSTINGCONFIGURATION']._serialized_start=733
  _globals['_AWSHOSTINGCONFIGURATION']._serialized_end=1003
  _globals['_GCPHOSTINGCONFIGURATION']._serialized_start=1006
  _globals['_GCPHOSTINGCONFIGURATION']._serialized_end=1190
  _globals['_GCPSERVICEACCOUNTAUTH']._serialized_start=1193
  _globals['_GCPSERVICEACCOUNTAUTH']._serialized_end=1424
  _globals['_IAMSERVICEACCOUNT']._serialized_start=1426
  _globals['_IAMSERVICEACCOUNT']._serialized_end=1464
  _globals['_AZUREHOSTINGCONFIGURATION']._serialized_start=1467
  _globals['_AZUREHOSTINGCONFIGURATION']._serialized_end=1636
# @@protoc_insertion_point(module_scope)
