"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SlackAppIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTED_SLACK_APP_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    SLACK_APP_SETTINGS_FIELD_NUMBER: builtins.int
    SLACK_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    @property
    def encrypted_slack_app_auth_config(self) -> global___SlackAppAuthConfig:
        """Encrypted Slack auth configuration"""
    @property
    def slack_app_settings(self) -> global___SlackAppSettings:
        """All Qwak Slack App settings"""
    @property
    def slack_system_secret(self) -> global___SlackSystemSecretDescriptor:
        """Slack system secret descriptor"""
    def __init__(
        self,
        *,
        encrypted_slack_app_auth_config: global___SlackAppAuthConfig | None = ...,
        slack_app_settings: global___SlackAppSettings | None = ...,
        slack_system_secret: global___SlackSystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "encrypted_slack_app_auth_config", b"encrypted_slack_app_auth_config", "slack_app_settings", b"slack_app_settings", "slack_system_secret", b"slack_system_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "encrypted_slack_app_auth_config", b"encrypted_slack_app_auth_config", "slack_app_settings", b"slack_app_settings", "slack_system_secret", b"slack_system_secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["slack_system_secret"] | None: ...

global___SlackAppIntegration = SlackAppIntegration

class SlackAppIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_APP_TEMPORARY_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def slack_app_temporary_credentials(self) -> global___SlackAppTemporaryCredentials: ...
    def __init__(
        self,
        *,
        slack_app_temporary_credentials: global___SlackAppTemporaryCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "slack_app_temporary_credentials", b"slack_app_temporary_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "slack_app_temporary_credentials", b"slack_app_temporary_credentials"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["slack_app_temporary_credentials"] | None: ...

global___SlackAppIntegrationSpec = SlackAppIntegrationSpec

class SlackAppTemporaryCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    REDIRECT_URI_FIELD_NUMBER: builtins.int
    state: builtins.str
    """A verification phrase generated by the app owner and required in order to validate the request"""
    code: builtins.str
    """A temporary Oauth2 token from slack"""
    redirect_uri: builtins.str
    """The redirect uri defined in the oauth url code"""
    def __init__(
        self,
        *,
        state: builtins.str = ...,
        code: builtins.str = ...,
        redirect_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "redirect_uri", b"redirect_uri", "state", b"state"]) -> None: ...

global___SlackAppTemporaryCredentials = SlackAppTemporaryCredentials

class SlackAppSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_TEAM_FIELD_NUMBER: builtins.int
    SLACK_ENTERPRISE_FIELD_NUMBER: builtins.int
    @property
    def slack_team(self) -> global___SlackTeam:
        """Slack team spec"""
    @property
    def slack_enterprise(self) -> global___SlackEnterprise: ...
    def __init__(
        self,
        *,
        slack_team: global___SlackTeam | None = ...,
        slack_enterprise: global___SlackEnterprise | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enterprise", b"enterprise", "slack_enterprise", b"slack_enterprise", "slack_team", b"slack_team"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enterprise", b"enterprise", "slack_enterprise", b"slack_enterprise", "slack_team", b"slack_team"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["enterprise", b"enterprise"]) -> typing_extensions.Literal["slack_enterprise"] | None: ...

global___SlackAppSettings = SlackAppSettings

class SlackAppAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOT_USER_TOKEN_FIELD_NUMBER: builtins.int
    bot_user_token: builtins.str
    def __init__(
        self,
        *,
        bot_user_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bot_user_token", b"bot_user_token"]) -> None: ...

global___SlackAppAuthConfig = SlackAppAuthConfig

class SlackSystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    URL_KEY_FIELD_NUMBER: builtins.int
    TOKEN_KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    """Slack system secret name"""
    url_key: builtins.str
    """Slack system secret url key"""
    token_key: builtins.str
    """Slack system secret token key"""
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        url_key: builtins.str = ...,
        token_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_name", b"secret_name", "token_key", b"token_key", "url_key", b"url_key"]) -> None: ...

global___SlackSystemSecretDescriptor = SlackSystemSecretDescriptor

class SlackAppValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SlackAppValidationSpec = SlackAppValidationSpec

class SlackAppIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SlackAppIntegrationOptions = SlackAppIntegrationOptions

class SlackTeam(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Slack team id"""
    name: builtins.str
    """Slack team name"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___SlackTeam = SlackTeam

class SlackEnterprise(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Slack enterprise id"""
    name: builtins.str
    """Slack enterprise name"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___SlackEnterprise = SlackEnterprise
