# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/data_versioning/data_versioning_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.data_versioning import data_versioning_pb2 as qwak_dot_data__versioning_dot_data__versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2qwak/data_versioning/data_versioning_service.proto\x12\x1fqwak.management.data_versioning\x1a*qwak/data_versioning/data_versioning.proto\"]\n\x16RegisterDataTagRequest\x12\x43\n\rdata_tag_spec\x18\x01 \x01(\x0b\x32,.qwak.management.data_versioning.DataTagSpec\"\x19\n\x17RegisterDataTagResponse\"}\n\x17GetModelDataTagsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12>\n\x06\x66ilter\x18\x03 \x01(\x0b\x32..qwak.management.data_versioning.DataTagFilter\"[\n\x18GetModelDataTagsResponse\x12?\n\tdata_tags\x18\x01 \x03(\x0b\x32,.qwak.management.data_versioning.DataTagSpec2\xb2\x02\n\x1f\x44\x61taVersioningManagementService\x12\x84\x01\n\x0fRegisterDataTag\x12\x37.qwak.management.data_versioning.RegisterDataTagRequest\x1a\x38.qwak.management.data_versioning.RegisterDataTagResponse\x12\x87\x01\n\x10GetModelDataTags\x12\x38.qwak.management.data_versioning.GetModelDataTagsRequest\x1a\x39.qwak.management.data_versioning.GetModelDataTagsResponseB/\n+com.qwak.ai.management.model_versioning.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.data_versioning.data_versioning_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.management.model_versioning.apiP\001'
  _globals['_REGISTERDATATAGREQUEST']._serialized_start=131
  _globals['_REGISTERDATATAGREQUEST']._serialized_end=224
  _globals['_REGISTERDATATAGRESPONSE']._serialized_start=226
  _globals['_REGISTERDATATAGRESPONSE']._serialized_end=251
  _globals['_GETMODELDATATAGSREQUEST']._serialized_start=253
  _globals['_GETMODELDATATAGSREQUEST']._serialized_end=378
  _globals['_GETMODELDATATAGSRESPONSE']._serialized_start=380
  _globals['_GETMODELDATATAGSRESPONSE']._serialized_end=471
  _globals['_DATAVERSIONINGMANAGEMENTSERVICE']._serialized_start=474
  _globals['_DATAVERSIONINGMANAGEMENTSERVICE']._serialized_end=780
# @@protoc_insertion_point(module_scope)
