# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/feature_store/features/monitoring.proto\x12&qwak.feature.store.features.monitoring\"b\n\x18MonitoringConfigurations\x12\x46\n\nmonitoring\x18\x01 \x03(\x0b\x32\x32.qwak.feature.store.features.monitoring.Monitoring\"c\n\nMonitoring\x12M\n\rfailure_alert\x18\x01 \x01(\x0b\x32\x34.qwak.feature.store.features.monitoring.FailureAlertH\x00\x42\x06\n\x04type\"\x1d\n\x0c\x46\x61ilureAlert\x12\r\n\x05names\x18\x01 \x03(\tB[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.monitoring_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _globals['_MONITORINGCONFIGURATIONS']._serialized_start=88
  _globals['_MONITORINGCONFIGURATIONS']._serialized_end=186
  _globals['_MONITORING']._serialized_start=188
  _globals['_MONITORING']._serialized_end=287
  _globals['_FAILUREALERT']._serialized_start=289
  _globals['_FAILUREALERT']._serialized_end=318
# @@protoc_insertion_point(module_scope)
