# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/kafka_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHqwak/administration/runtime_configuration/v0/external/kafka_config.proto\x12\x42qwak.administration.runtime_configuration.v0.external.kafka_config\x1a=qwak/administration/runtime_configuration/v0/creds/auth.proto\"\x8f\x02\n\x12KafkaConfiguration\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12X\n\nbasic_auth\x18\x02 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.creds.auth.BasicAuthH\x00\x12|\n\x11security_protocol\x18\x03 \x01(\x0b\x32_.qwak.administration.runtime_configuration.v0.external.kafka_config.KafkaSecurityProtocolConfigH\x00\x42\x06\n\x04\x61uth\"\xa5\x02\n\x1bKafkaSecurityProtocolConfig\x12~\n\nplain_text\x18\x01 \x01(\x0b\x32h.qwak.administration.runtime_configuration.v0.external.kafka_config.KafkaPlainTextSecurityProtocolConfigH\x00\x12q\n\x03ssl\x18\x02 \x01(\x0b\x32\x62.qwak.administration.runtime_configuration.v0.external.kafka_config.KafkaSslSecurityProtocolConfigH\x00\x42\x13\n\x11security_protocol\"&\n$KafkaPlainTextSecurityProtocolConfig\" \n\x1eKafkaSslSecurityProtocolConfigB\xf4\x01\n;com.jfrog.ml.runtime_configuration.v0.external.kafka_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.external.kafka_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;com.jfrog.ml.runtime_configuration.v0.external.kafka_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _globals['_KAFKACONFIGURATION']._serialized_start=208
  _globals['_KAFKACONFIGURATION']._serialized_end=479
  _globals['_KAFKASECURITYPROTOCOLCONFIG']._serialized_start=482
  _globals['_KAFKASECURITYPROTOCOLCONFIG']._serialized_end=775
  _globals['_KAFKAPLAINTEXTSECURITYPROTOCOLCONFIG']._serialized_start=777
  _globals['_KAFKAPLAINTEXTSECURITYPROTOCOLCONFIG']._serialized_end=815
  _globals['_KAFKASSLSECURITYPROTOCOLCONFIG']._serialized_start=817
  _globals['_KAFKASSLSECURITYPROTOCOLCONFIG']._serialized_end=849
# @@protoc_insertion_point(module_scope)
