# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.build_settings import build_settings_api_pb2 as qwak_dot_build__settings_dot_build__settings__api__pb2


class BuildSettingsApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SaveBuildSettings = channel.unary_unary(
                '/com.qwak.build_settings.BuildSettingsApi/SaveBuildSettings',
                request_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsResponse.FromString,
                )
        self.GetBuildSettings = channel.unary_unary(
                '/com.qwak.build_settings.BuildSettingsApi/GetBuildSettings',
                request_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsResponse.FromString,
                )
        self.DeleteBuildSettings = channel.unary_unary(
                '/com.qwak.build_settings.BuildSettingsApi/DeleteBuildSettings',
                request_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsResponse.FromString,
                )


class BuildSettingsApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SaveBuildSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBuildSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BuildSettingsApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SaveBuildSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveBuildSettings,
                    request_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsRequest.FromString,
                    response_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsResponse.SerializeToString,
            ),
            'GetBuildSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildSettings,
                    request_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsRequest.FromString,
                    response_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsResponse.SerializeToString,
            ),
            'DeleteBuildSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBuildSettings,
                    request_deserializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsRequest.FromString,
                    response_serializer=qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.qwak.build_settings.BuildSettingsApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BuildSettingsApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SaveBuildSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build_settings.BuildSettingsApi/SaveBuildSettings',
            qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsRequest.SerializeToString,
            qwak_dot_build__settings_dot_build__settings__api__pb2.SaveBuildSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build_settings.BuildSettingsApi/GetBuildSettings',
            qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsRequest.SerializeToString,
            qwak_dot_build__settings_dot_build__settings__api__pb2.GetBuildSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBuildSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build_settings.BuildSettingsApi/DeleteBuildSettings',
            qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsRequest.SerializeToString,
            qwak_dot_build__settings_dot_build__settings__api__pb2.DeleteBuildSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
